==> checkstyle_7.5.1.orig.tar.xz: checkstyle-7.5.1/README.md <==
[![][travis img]][travis]
[![][appveyor img]][appveyor]
[![][teamcity img]][teamcity]
[![][codeship img]][codeship]
[![][circleci img]][circleci]
[![][wercker img]][wercker]
[![][shippable img]][shippable]
[![][coverage img]][coverage]

[![][mavenbadge img]][mavenbadge]
[![][versioneye img]][versioneye]
[![][sonar img]][sonar]

Members chat: [![][gitter img]][gitter]
Contributors chat: [![https://gitter.im/checkstyle/checkstyle](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/checkstyle/checkstyle?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

![](https://raw.githubusercontent.com/checkstyle/resources/master/img/checkstyle-logos/checkstyle-logo-260x99.png)

Checkstyle is a tool for
checking Java source code for adherence to a Code Standard or set of validation rules (best practices).

The latest release version can be found at [SourceForge downloads](https://sourceforge.net/projects/checkstyle/files/checkstyle/) or at [Maven repo](http://repo1.maven.org/maven2/com/puppycrawl/tools/checkstyle/).

Each-commit builds of maven artifacts can be found at [Maven Snapshot repository](https://oss.sonatype.org/content/repositories/snapshots/com/puppycrawl/tools/checkstyle/).

Documentation is available in HTML format, see http://checkstyle.sourceforge.net/checks.html.

Continuous integration and Quality reports
======================
Travis (Linux & MacOS build): [![][travis img]][travis]
Appveyor (Windows build): [![][appveyor img]][appveyor]
[Distelli CI](https://www.distelli.com/checkstyle/builds)

Quality reports: http://checkstyle.sourceforge.net/project-reports.html

JavaScript, CSS and Java source file analysis on Codacy: [![][codacy img]][codacy]

Feedback/Support
========

Please send any feedback to https://groups.google.com/forum/?hl=en#!forum/checkstyle

Questions and Answers from community: [![][stackoverflow img]][stackoverflow]

Bugs and Feature requests (not a questions): https://github.com/checkstyle/checkstyle/issues

Licensing
=========

[![][license img]][license]

This software is licensed under the terms in the file named "LICENSE" in this
directory.

The software uses the ANTLR package (http://www.antlr.org). Its license terms
are in the file named "RIGHTS.antlr" in this directory.

This product includes software developed by
The Apache Software Foundation (http://www.apache.org/).

The software uses the Cli, Logging and Beanutils packages from the
Apache Commons project (http://commons.apache.org/). The license terms
of these packages are in the file named "LICENSE.apache20" in this
directory.

The software uses the Google Guava Libraries
(https://code.google.com/p/guava-libraries/). The license terms of
these packages are in the file named "LICENSE.apache20" in this
directory.

[travis]:https://travis-ci.org/checkstyle/checkstyle/builds
[travis img]:https://secure.travis-ci.org/checkstyle/checkstyle.png

[appveyor]:https://ci.appveyor.com/project/checkstyle/checkstyle/history
[appveyor img]:https://ci.appveyor.com/api/projects/status/rw6bw3dl9kph6ucc?svg=true

[sonar]:https://sonarqube.com/overview?id=com.puppycrawl.tools%3Acheckstyle
[sonar img]:https://img.shields.io/sonar/http/sonarqube.com/com.puppycrawl.tools:checkstyle/tech_debt.svg?label=Sonarqube%20tech%20debt

[codacy]:https://www.codacy.com/app/checkstyle/checkstyle
[codacy img]:https://api.codacy.com/project/badge/3adf12d434314ba8b38277ea46d3c44b

[coverage]:http://codecov.io/github/checkstyle/checkstyle?branch=master
[coverage img]:http://codecov.io/github/checkstyle/checkstyle/coverage.svg?branch=master

[license]:LICENSE
[license img]:https://img.shields.io/badge/license-GNU%20LGPL%20v2.1-blue.svg

[mavenbadge]:http://search.maven.org/#search|gav|1|g%3A%22com.puppycrawl.tools%22%20AND%20a%3A%22checkstyle%22
[mavenbadge img]:https://maven-badges.herokuapp.com/maven-central/com.puppycrawl.tools/checkstyle/badge.svg

[versioneye]:https://www.versioneye.com/user/projects/5504ca834a1064774400049a
[versioneye img]:https://www.versioneye.com/user/projects/5504ca834a1064774400049a/badge.svg

[gitter]:https://gitter.im/checkstyle
[gitter img]:http://img.shields.io/badge/gitter-JOIN%20CHAT-blue.svg

[gitterpublic]:https://gitter.im/checkstyle/checkstyle
[gitterpublic img]:https://badges.gitter.im/Join%20Chat.svg)

[stackoverflow]:http://stackoverflow.com/questions/tagged/checkstyle
[stackoverflow img]:https://img.shields.io/badge/stackoverflow-CHECKSTYLE-blue.svg

[teamcity]:https://teamcity.jetbrains.com/viewType.html?buildTypeId=Checkstyle_IdeaInspectionsMaster
[teamcity img]:https://img.shields.io/teamcity/http/teamcity.jetbrains.com/s/Checkstyle_IdeaInspectionsMaster.svg?label=TeamCity%20inspections

[codeship]: https://codeship.com/projects/124310
[codeship img]:https://codeship.com/projects/67b814a0-8fee-0133-9b59-02a170289b8c/status?branch=master

[circleci]: https://circleci.com/gh/checkstyle/checkstyle/tree/master
[circleci img]: https://circleci.com/gh/checkstyle/checkstyle/tree/master.svg?style=svg

[wercker]: https://app.wercker.com/project/bykey/cd383127330ff96f89f1a78e8fd1a557
[wercker img]: https://app.wercker.com/status/cd383127330ff96f89f1a78e8fd1a557/s/master

[shippable]: https://app.shippable.com/projects/577032be3be4f4faa56adb38
[shippable img]: https://img.shields.io/shippable/577032be3be4f4faa56adb38/master.svg?label=shippable

==> checkstyle_8.8.orig.tar.xz: checkstyle-8.8/README.md <==
[![][travis img]][travis]
[![][appveyor img]][appveyor]
[![][teamcity img]][teamcity]
[![][codeship img]][codeship]
[![][circleci img]][circleci]
[![][wercker img]][wercker]
[![][shippable img]][shippable]
[![][coverage img]][coverage]

[![][mavenbadge img]][mavenbadge]
[![][sonar img]][sonar]

Members chat: [![][gitter_mem img]][gitter_mem]
Contributors chat: [![][gitter_con img]][gitter_con]

![](https://raw.githubusercontent.com/checkstyle/resources/master/img/checkstyle-logos/checkstyle-logo-260x99.png)

Checkstyle is a tool for
checking Java source code for adherence to a Code Standard or set of validation rules (best practices).

The latest release version can be found at [SourceForge downloads](https://sourceforge.net/projects/checkstyle/files/checkstyle/) or at [Maven repo](http://repo1.maven.org/maven2/com/puppycrawl/tools/checkstyle/).

Each-commit builds of maven artifacts can be found at [Maven Snapshot repository](https://oss.sonatype.org/content/repositories/snapshots/com/puppycrawl/tools/checkstyle/).

Documentation is available in HTML format, see http://checkstyle.sourceforge.net/checks.html.

Continuous integration and Quality reports
======================
Travis (Linux & MacOS build): [![][travis img]][travis]
Appveyor (Windows build): [![][appveyor img]][appveyor]
[Distelli CI](https://www.distelli.com/checkstyle/builds)

Quality reports: http://checkstyle.sourceforge.net/project-reports.html

JavaScript, CSS and Java source file analysis on Codacy: [![][codacy img]][codacy]

Feedback/Support
========

Please send any feedback to https://groups.google.com/forum/?hl=en#!forum/checkstyle

Questions and Answers from community: [![][stackoverflow img]][stackoverflow]

Bugs and Feature requests (not the questions): https://github.com/checkstyle/checkstyle/issues

Licensing
=========

[![][license img]][license]

This software is licensed under the terms in the file named "LICENSE" in this
directory.

The software uses the ANTLR package (http://www.antlr.org/). Its license terms
are in the file named "RIGHTS.antlr" in this directory.

This product includes software developed by
The Apache Software Foundation (http://www.apache.org/).

The software uses the Cli, Logging and Beanutils packages from the
Apache Commons project (http://commons.apache.org/). The license terms
of these packages are in the file named "LICENSE.apache20" in this
directory.

The software uses the Google Guava Libraries
(https://code.google.com/p/guava-libraries/). The license terms of
these packages are in the file named "LICENSE.apache20" in this
directory.

[travis]:https://travis-ci.org/checkstyle/checkstyle/builds
[travis img]:https://travis-ci.org/checkstyle/checkstyle.svg

[appveyor]:https://ci.appveyor.com/project/checkstyle/checkstyle/history
[appveyor img]:https://ci.appveyor.com/api/projects/status/rw6bw3dl9kph6ucc?svg=true

[sonar]:https://sonarcloud.io/dashboard?id=com.puppycrawl.tools%3Acheckstyle
[sonar img]:https://sonarcloud.io/api/badges/measure?key=com.puppycrawl.tools:checkstyle&metric=sqale_debt_ratio

[codacy]:https://www.codacy.com/app/checkstyle/checkstyle
[codacy img]:https://api.codacy.com/project/badge/3adf12d434314ba8b38277ea46d3c44b

[coverage]:https://codecov.io/github/checkstyle/checkstyle?branch=master
[coverage img]:https://codecov.io/github/checkstyle/checkstyle/coverage.svg?branch=master

[license]:LICENSE
[license img]:https://img.shields.io/badge/license-GNU%20LGPL%20v2.1-blue.svg

[mavenbadge]:https://search.maven.org/#search|gav|1|g%3A%22com.puppycrawl.tools%22%20AND%20a%3A%22checkstyle%22
[mavenbadge img]:https://maven-badges.herokuapp.com/maven-central/com.puppycrawl.tools/checkstyle/badge.svg

[gitter_mem]:https://gitter.im/checkstyle
[gitter_mem img]:https://img.shields.io/badge/gitter-JOIN%20CHAT-blue.svg

[gitter_con]:https://gitter.im/checkstyle/checkstyle
[gitter_con img]:https://badges.gitter.im/Join%20Chat.svg

[stackoverflow]:https://stackoverflow.com/questions/tagged/checkstyle
[stackoverflow img]:https://img.shields.io/badge/stackoverflow-CHECKSTYLE-blue.svg

[teamcity]:https://teamcity.jetbrains.com/viewType.html?buildTypeId=Checkstyle_IdeaInspectionsMaster
[teamcity img]:https://img.shields.io/teamcity/http/teamcity.jetbrains.com/s/Checkstyle_IdeaInspectionsMaster.svg?label=TeamCity%20inspections

[codeship]: https://codeship.com/projects/124310
[codeship img]:https://codeship.com/projects/67b814a0-8fee-0133-9b59-02a170289b8c/status?branch=master

[circleci]: https://circleci.com/gh/checkstyle/checkstyle/tree/master
[circleci img]: https://circleci.com/gh/checkstyle/checkstyle/tree/master.svg?style=svg

[wercker]: https://app.wercker.com/project/bykey/cd383127330ff96f89f1a78e8fd1a557
[wercker img]: https://app.wercker.com/status/cd383127330ff96f89f1a78e8fd1a557/s/master

[shippable]: https://app.shippable.com/projects/577032be3be4f4faa56adb38
[shippable img]: https://img.shields.io/shippable/577032be3be4f4faa56adb38/master.svg?label=shippable
